Enum style::properties::animated_properties::TransitionProperty
[−]
[src]
pub enum TransitionProperty {
All,
Shorthand(ShorthandId),
Longhand(LonghandId),
Unsupported(CustomIdent),
}A given transition property, that is either All, a transitionable longhand property,
a shorthand with at least one transitionable longhand component, or an unsupported property.
Variants
AllAll, any transitionable property changing should generate a transition.
FIXME(emilio): Can we remove this and just use Shorthand(ShorthandId::All)?
Shorthand(ShorthandId)A shorthand.
Longhand(LonghandId)A longhand transitionable property.
Unsupported(CustomIdent)Unrecognized property which could be any non-transitionable, custom property, or unknown property.
Methods
impl TransitionProperty[src]
pub fn each<F: FnMut(&LonghandId)>(cb: F)[src]
Iterates over each longhand property.
pub fn any<F: FnMut(&LonghandId) -> bool>(cb: F) -> bool[src]
Iterates over every longhand property that is not TransitionProperty::All, stopping and returning true when the provided callback returns true for the first time.
pub fn parse<'i, 't>(input: &mut Parser<'i, 't>) -> Result<Self, ParseError<'i>>[src]
Parse a transition-property value.